function [prdData, info] = predict_Hexagrammos_stelleri(par, data, auxData)
  
  % unpack par, data, auxData
  cPar = parscomp_st(par); vars_pull(par); 
  vars_pull(cPar);  vars_pull(data);  vars_pull(auxData);
        
  % compute temperature correction factors
  TC = tempcorr(temp.am, T_ref, T_A);
  
  % zero-variate data

  % life cycle
  pars_tj = [g k l_T v_Hb v_Hj v_Hp];
  [t_j, t_p, t_b, l_j, l_p, l_b, l_i, rho_j, rho_B, info] = get_tj(pars_tj, f);
  
  % birth
  L_b = L_m * l_b;                  % cm, structural length at birth at f
  Ww_b = L_b^3 * (1 + f * w);      % g, wet weight at birth


  % puberty 
  L_p = L_m * l_p;                  % cm, structural length at puberty at f
  Lw_p = L_p/ del_M;                % cm, physical length at puberty at f
  Ww_p = L_p^3 * (1 + f * w);       % g, wet weight at puberty

  % ultimate
  L_i = L_m * l_i;                  % cm, ultimate structural length at f
  Lw_i = L_i/ del_M;                % cm, ultimate physical length at f
  Ww_i = L_i^3 * (1 + f * w);       % g, ultimate wet weight 
 
  % reproduction
  pars_R = [kap; kap_R; g; k_J; k_M; L_T; v; U_Hb; U_Hj; U_Hp]; % compose parameter vector at T
  RT_i = TC * reprod_rate_j(L_i, f, pars_R);                   % #/d, ultimate reproduction rate at T


  % life span
  pars_tm = [g; l_T; h_a/ k_M^2; s_G];  % compose parameter vector at T_ref
  t_m = get_tm_s(pars_tm, f, l_b);      % -, scaled mean life span at T_ref
  aT_m = t_m/ k_M/ TC;                  % d, mean life span at T
     
  % males
  p_Am_m = z_m * p_M/ kap;             % J/d.cm^2, {p_Am} max spec assimilation flux for males
  E_m_m = p_Am_m/ v;                   % J/cm^3, [E_m] reserve capacity for males
  g_m = E_G/ kap/ E_m_m;               % -, energy investment ratio for males
  L_mm = v/ k_M/ g_m;                  % cm, maximum structural length for males
  m_Em_m = y_E_V * E_m_m/ E_G;         % mol/mol, reserve capacity 
  w_m = m_Em_m * w_E/ w_V;             % -, contribution of reserve to weight
  pars_tjm = [g_m k l_T v_Hb v_Hj v_Hp];
  
  % pack to output
  prdData.am = aT_m;
  prdData.Lp = Lw_p;
  prdData.Li = Lw_i;
  prdData.Wwb = Ww_b;
  prdData.Wwp = Ww_p;
  prdData.Wwi = Ww_i;
  prdData.Ri = RT_i;
  
  % uni-variate data
  
  % time-length/weight 
  % females
  [t_j, t_p, t_b, l_j, l_p, l_b, l_i, rho_j, rho_B, info] = get_tj(pars_tj, f_tL);
  L_b = L_m * l_b; L_j = L_m * l_j; L_i = L_m * l_i;
  kT_M = k_M * TC; rT_j = kT_M * rho_j; rT_B = kT_M * rho_B; tT_j = (t_j - t_b)/ kT_M;
  L_bj = L_b * exp(tL_f(tL_f(:,1) < tT_j,1) * rT_j/ 3);
  %
  L_ji = L_i - (L_i - L_j) * exp( - rT_B * (tL_f(tL_f(:,1) >= tT_j,1) - tT_j)); % cm, expected length at time
  ELw_f = [L_bj; L_ji]/ del_M; % g, total length
  %
  L_bj = L_b * exp(tW_f(tW_f(:,1) < tT_j,1) * rT_j/ 3);
  L_ji = L_i - (L_i - L_j) * exp( - rT_B * (tW_f(tW_f(:,1) >= tT_j,1) - tT_j)); % cm, expected length at time
  EWw_f = [L_bj; L_ji].^3 * (1 + f_tL * w); % g, wet weight
  % males
  [t_jm, t_pm, t_bm, l_jm, l_pm, l_bm, l_im, rho_jm, rho_Bm] = get_tj(pars_tjm, f);
  L_bm = L_mm * l_bm; L_jm = L_mm * l_jm; L_im = L_mm * l_im;
  rT_Bm = rho_Bm * kT_M; rT_jm = rho_jm * kT_M; tT_jm = (t_jm - t_bm)/ kT_M;
  L_bj = L_bm * exp(tL_m(tL_m(:,1) < tT_jm,1) * rT_jm/ 3);
  L_ji = L_im - (L_im - L_jm) * exp( - rT_Bm * (tL_m(tL_m(:,1) >= tT_jm,1) - tT_jm)); % cm, expected length at time
  ELw_m = [L_bj; L_ji]/ del_M;
  %
  L_bj = L_bm * exp(tW_m(tW_m(:,1) < tT_jm,1) * rT_jm/ 3);
  L_ji = L_im - (L_im - L_jm) * exp( - rT_B * (tW_m(tW_m(:,1) >= tT_jm,1) - tT_jm)); % cm, expected length at time
  EWw_m = [L_bj; L_ji].^3 * (1 + f_tL * w_m);;

  % pack to output
  prdData.tL_f = ELw_f;
  prdData.tL_m = ELw_m;
  prdData.tW_f = EWw_f;
  prdData.tW_m = EWw_m;
